from django.apps import AppConfig


class DjangoRootSecretConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_root_secret"
    verbose_name = "Django Root Secret"
